@@ -9,7 +9,7 @@ from utilitylibrary.unique import gennerate_unique
 
 def split_mime_type(filename):
     mimeType = filename.split(".")
-    return mimeType[1]
+    return mimeType[-1]
 
 
 '''
